@@ -1,5 +1,10 @@
 # flake8: noqa
 
+
+def register_plugin(registry):
+    registry.set_plugin_version('rastervision.pytorch_backend', 1)
+
+
 import rastervision.pipeline
 from rastervision.pytorch_backend.pytorch_chip_classification_config import *
 from rastervision.pytorch_backend.pytorch_chip_classification import *
@@ -8,8 +13,11 @@ from rastervision.pytorch_backend.pytorch_semantic_segmentation import *
 from rastervision.pytorch_backend.pytorch_object_detection_config import *
 from rastervision.pytorch_backend.pytorch_object_detection import *
 
-
-def register_plugin(registry):
-    registry.set_plugin_version('rastervision.pytorch_backend', 1)
-    registry.set_plugin_aliases('rastervision.pytorch_backend',
-                                ['rastervision2.pytorch_backend'])
+__all__ = [
+    PyTorchChipClassification.__name__,
+    PyTorchChipClassificationConfig.__name__,
+    PyTorchSemanticSegmentation.__name__,
+    PyTorchSemanticSegmentationConfig.__name__,
+    PyTorchObjectDetection.__name__,
+    PyTorchObjectDetectionConfig.__name__,
+]
