@@ -45,7 +45,7 @@ def get_config(runner,
     Args:
         runner (Runner): Runner for the pipeline. Will be provided by RV.
         raw_uri (str): Directory where the raw data resides
-        processed_uri (str): Directory for storing processed data. 
+        processed_uri (str): Directory for storing processed data.
                              E.g. crops for testing.
         root_uri (str): Directory where all the output will be written.
         multiband (bool, optional): If True, all 4 channels (R, G, B, & IR)
@@ -105,7 +105,6 @@ def get_config(runner,
         plot_transform = None
 
     class_config = ClassConfig(names=CLASS_NAMES, colors=CLASS_COLORS)
-    class_config.ensure_null_class()
 
     def make_scene(id) -> SceneConfig:
         id = id.replace('-', '_')
@@ -131,8 +130,11 @@ def get_config(runner,
         # Using with_rgb_class_map because label TIFFs have classes encoded as
         # RGB colors.
         label_source = SemanticSegmentationLabelSourceConfig(
-            rgb_class_config=class_config,
-            raster_source=RasterioSourceConfig(uris=[label_uri]))
+            raster_source=RasterioSourceConfig(
+                uris=[label_uri],
+                transformers=[
+                    RGBClassTransformerConfig(class_config=class_config)
+                ]))
 
         # URI will be injected by scene config.
         # Using rgb=True because we want prediction TIFFs to be in
@@ -181,10 +183,11 @@ def get_config(runner,
             img_sz=img_sz,
             img_channels=len(channel_order),
             num_workers=4,
-            channel_display_groups=channel_display_groups,
             base_transform=base_transform,
             aug_transform=aug_transform,
-            plot_options=PlotOptions(transform=plot_transform))
+            plot_options=PlotOptions(
+                transform=plot_transform,
+                channel_display_groups=channel_display_groups))
     else:
         data = SemanticSegmentationImageDataConfig(
             img_sz=img_sz,
@@ -192,9 +195,13 @@ def get_config(runner,
             channel_display_groups=channel_display_groups,
             base_transform=base_transform,
             aug_transform=aug_transform,
-            plot_options=PlotOptions(transform=plot_transform))
+            plot_options=PlotOptions(
+                transform=plot_transform,
+                channel_display_groups=channel_display_groups))
 
     if external_model:
+        class_config.ensure_null_class()
+        num_classes = len(class_config)
         model = SemanticSegmentationModelConfig(
             external_def=ExternalModuleConfig(
                 github_repo='AdeelH/pytorch-fpn:0.2',
@@ -203,7 +210,7 @@ def get_config(runner,
                 entrypoint_kwargs={
                     'name': 'resnet50',
                     'fpn_type': 'panoptic',
-                    'num_classes': len(class_config.names),
+                    'num_classes': num_classes,
                     'fpn_channels': 256,
                     'in_channels': len(channel_order),
                     'out_size': (img_sz, img_sz)
@@ -229,7 +236,6 @@ def get_config(runner,
         root_uri=root_uri,
         dataset=scene_dataset,
         backend=backend,
-        channel_display_groups=channel_display_groups,
         train_chip_sz=chip_sz,
         predict_chip_sz=chip_sz,
         chip_options=chip_options)
