@@ -103,9 +103,13 @@ def build_scene(spacenet_cfg: SpacenetConfig,
     # Set a line buffer to convert line strings to polygons.
     vector_source = GeoJSONVectorSourceConfig(
         uri=label_uri,
-        default_class_id=0,
         ignore_crs_field=True,
-        line_bufs={0: 15})
+        transformers=[
+            ClassInferenceTransformerConfig(default_class_id=0),
+            BufferTransformerConfig(
+                geom_type='LineString', class_bufs={0: 15}),
+            BufferTransformerConfig(geom_type='Point'),
+        ])
     label_source = SemanticSegmentationLabelSourceConfig(
         raster_source=RasterizedSourceConfig(
             vector_source=vector_source,
@@ -224,5 +228,4 @@ def get_config(runner,
         backend=backend,
         train_chip_sz=chip_sz,
         predict_chip_sz=chip_sz,
-        img_format='npy',
         chip_options=chip_options)
